From ba50f64c2fd53db7e416f5a7c10419f37e466595 Mon Sep 17 00:00:00 2001
From: Carlos Lopez-Camey <c.lopez@kmels.net>
Date: Sat, 16 Jun 2012 12:00:49 +0200
Subject: [PATCH] Add Data.List.findSublistIndex. It finds the index of a
 sublist in a list

---
 Data/List.hs |   13 +++++++++++++
 1 file changed, 13 insertions(+)

diff --git a/Data/List.hs b/Data/List.hs
index 7b06dae..dfce93d 100644
--- a/Data/List.hs
+++ b/Data/List.hs
@@ -134,6 +134,7 @@ module Data.List
 
    , findIndex         -- :: (a -> Bool) -> [a] -> Maybe Int
    , findIndices       -- :: (a -> Bool) -> [a] -> [Int]
+   , findSublistIndex  -- :: (Eq a) => [a] -> [a] -> Maybe Int
 
    -- * Zipping and unzipping lists
 
@@ -291,6 +292,18 @@ findIndices p ls = loop 0# ls
                                  | otherwise = loop (n +# 1#) xs
 #endif  /* USE_REPORT_PRELUDE */
 
+-- | Receives a sublist and a list. It returns the index where the sublist appears in the list. For example:
+--
+-- > findSublistIndex "abc" "abcabbc" == Just 0
+-- > findSublistIndex findSublistIndex [5,6] [1..] == Just 4
+-- > findSublistIndex "abbc" "abcabbc" == Just 3
+-- > findSublistIndex [2,1] [2,4..10] == Nothing
+findSublistIndex :: (Eq a) => [a] -> [a] -> Maybe Int
+findSublistIndex [] _ = Nothing
+findSublistIndex sublist list = findSeqIndex sublist list 0 where
+  findSeqIndex _ [] _ = Nothing
+  findSeqIndex sublist' list'@(x:xs) i = if (sublist' `isPrefixOf` list') then Just i else findSeqIndex sublist' xs  (i+1)  
+    
 -- | The 'isPrefixOf' function takes two lists and returns 'True'
 -- iff the first list is a prefix of the second.
 isPrefixOf              :: (Eq a) => [a] -> [a] -> Bool
-- 
1.7.9.5

